Message

Enum Message 

pub enum Message<P = Box<RawMessage>> {
    Transfer {
        amount: Amount,
        token_address: Address,
        token_chain: Chain,
        recipient: Address,
        recipient_chain: Chain,
        fee: Amount,
    },
    AssetMeta {
        token_address: Address,
        token_chain: Chain,
        decimals: u8,
        symbol: BString,
        name: BString,
    },
    TransferWithPayload {
        amount: Amount,
        token_address: Address,
        token_chain: Chain,
        recipient: Address,
        recipient_chain: Chain,
        sender_address: Address,
        payload: P,
    },
}
Represents a non-governance action targeted at the token bridge.

The generic parameter P indicates the type of the payload for the TransferWithPayload variant. This defaults to Box<RawMessage> as that provides the most flexibility when deserializing the payload and avoids leaking lifetime parameters higher up the stack. However, users who are serializing to or deserializing from the serde_wormhole data format may want to use a &RawMessage to avoid unnecessary memory allocations. When the type of the payload is known and is serialized in the same data format as the rest of the message, that type can be used as the generic parameter to deserialize the message and the payload together.

Variants



Transfer

The Transfer message contains specifics detailing a token lock up on a sending chain. Chains that are attempting to initiate a transfer must lock up tokens in some manner, such as in a custody account or via burning, before emitting this message.

Fields

amount: Amount

The amount being transferred.

token_address: Address

Address of the token. Left-zero-padded if shorter than 32 bytes.

token_chain: Chain

Chain ID of the token.

recipient: Address

Address of the recipient. Left-zero-padded if shorter than 32 bytes.

recipient_chain: Chain

Chain ID of the recipient.

fee: Amount

Amount that the user is willing to pay as the relayer fee. Must be <= amount.



AssetMeta

Contains information about a token and its origin chain.

Fields

token_address: Address

Address of the token. Left-zero-padded if shorter than 32 bytes.

token_chain: Chain

Chain ID of the token.

decimals: u8

Number of decimals in the token.

symbol: BString

Symbol of the token.

name: BString

Name of the token.



TransferWithPayload

Similar to Transfer but also includes an arbitrary payload.

Examples

Deserialize a TransferWithPayload message using the serde_wormhole crate:

      use serde_wormhole::RawMessage;
      use wormhole_sdk::{token::Message, Vaa};

      let msg = serde_wormhole::from_slice::<Vaa<Message<&RawMessage>>>(&data)?;
      match msg.payload {
          Message::TransferWithPayload { payload, .. } => {
              // Handle the payload.
          }
          _ => {
              // Handle other message types.    
          }
      }

Deserialize a TransferWithPayload message using serde_json:

      use anyhow::anyhow;
      use wormhole_sdk::{token::Message, Vaa};

      let msg = serde_json::from_slice::<Vaa<Message>>(&data)?;
      match msg.payload {
          Message::TransferWithPayload { payload, .. } => {
              // Handle the payload.
          }
          _ => {
              // Handle other message types.    
          }
      }

Fields

amount: Amount

The amount being transferred.

token_address: Address

Address of the token. Left-zero-padded if shorter than 32 bytes.

token_chain: Chain

Chain ID of the token.

recipient: Address

Address of the recipient. Left-zero-padded if shorter than 32 bytes.

recipient_chain: Chain

Chain ID of the recipient.

sender_address: Address

The identity of the sender sending the payload.

payload: P

The payload to be included with the transfer.